Manhattan Distance
====================================
Definition: The distance between two points measured along axes at right angles.
====================================

This library allows you to calculate the Manhattan Distance between two points using their coordinates.

Usage: mandist(lat_from, lon_from, lat_to, lon_to) You can use ints or floats.